from splinter.browser import Browser
# from django.conf import settings

browser = Browser()
# browser.visit('%s/admin' % settings.BASE_URL)

# browser.fill('username', 'test')
# browser.fill('password', 'test')
# browser.find_by_css('.btn-login').click()
